@@ -15,10 +15,17 @@
 #define SIG_SEQ_MIN 1
 #define SIG_SEQ_MAX 3
 
+typedef struct {
+
+    short strict_signature;
+
+} my_stack_opts_t;
+
 typedef struct {
 
     int size;
     intptr_t * data;
+    my_stack_opts_t * opts;
 
 } my_stack_t;
 
