@@ -155,7 +155,7 @@ sub build_validator {
     };
 }
 
-=head2 sign( ArrayRef $signature )
+=head2 sign( ArrayRef signature, HashRef options )
 
 Генерирует валидатор для текущего типа на основе подписи.
 
@@ -163,7 +163,7 @@ sub build_validator {
 
 sub sign {
 
-    my ( $self, $signature ) = @_;
+    my ( $self, $signature, $options ) = @_;
 
     my $signed_type_generator = $self -> signed_type_generator();
 
@@ -172,7 +172,7 @@ sub sign {
         die( sprintf( 'Type %s cannot be signed', $self -> name() ) )
     }
 
-    my $signed_validator = $signed_type_generator -> ( $signature );
+    my $signed_validator = $signed_type_generator -> ( $signature, $options );
 
     return sub {
 
