@@ -1,19 +1,23 @@
 package Salvation::TC::Type::Date;
 
 use strict;
-use base qw( Salvation::TC::Type );
-use Error qw ( :try );
-use Salvation::TC::Type::Time;
-use Salvation::TC::Exception::WrongType;
+use warnings;
+
+use base 'Salvation::TC::Type';
+
+use Salvation::TC::Type::Time ();
+use Salvation::TC::Exception::WrongType ();
 use Time::Piece ();
 
+my $re = qr/^(\d{1,2})[\.\/\-](\d{1,2})[\.\/\-](\d{4})\s*(\d+:\d+(:\d+)*?)?$/;
+
 sub Check {
 
     my ( $class, $date ) = @_;
 
-    try {
+    eval {
 
-        die "Wrong date format. Expected day[.-/]month[./-]year time" if ( ! defined( $date ) || $date !~ m/^(\d{1,2})[\.\/\-](\d{1,2})[\.\/\-](\d{4})\s*(\d+:\d+(:\d+)*?)?$/ );
+        die "Wrong date format. Expected day[.-/]month[./-]year time" if ( ! defined( $date ) || $date !~ $re );
 
         my ( $day, $month, $year, $time ) = ( $1, $2, $3, $4 );
 
@@ -24,10 +28,11 @@ sub Check {
         Salvation::TC::Type::Time->Check( $time ) if ( $time );
 
         defined( Time::Piece -> strptime( "$year-$month-$day", '%Y-%m-%d' ) ) || die "Unknow date format: $date.";
-    }
-    otherwise {
-        my $e = shift( @_ );
-        throw Salvation::TC::Exception::WrongType( 'type' => 'Date', 'value' => $date, '-text' => $e->stacktrace() );
+    };
+
+    if( $@ ) {
+
+        Salvation::TC::Exception::WrongType -> throw( type => 'Date', value => $date );
     };
 }
 
